@@ -657,7 +657,7 @@ def call_import(filepath):
     print("importing ")
     print(filepath)
     if importtype == "trx" and replaceretry == "true":
-        with open(filepath, 'r') as openfile :
+        with open(filepath, 'r', errors='ignore') as openfile :
             filedata = openfile.read()
 
             # Replace the target string
